#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 postgrest
version:              10.1.0
visibility:           public
id:                   postgrest-10.1.0-EgJ93pZDzZuJRyYSfSIiN1
key:                  postgrest-10.1.0-EgJ93pZDzZuJRyYSfSIiN1
license:              MIT
maintainer:           Steve Chavez <stevechavezast@gmail.com>
author:               Joe Nelson, Adam Baker, Steve Chavez
homepage:             https://postgrest.org
synopsis:             REST API for any Postgres database
description:
    Reads the schema of a PostgreSQL database and creates RESTful routes
    for tables, views, and functions, supporting all HTTP methods that security
    permits.

category:             Executable, PostgreSQL, Network APIs
abi:                  cef2fb93ce2413f04bbb2a2a4194d781
exposed:              True
exposed-modules:
    PostgREST.ApiRequest PostgREST.ApiRequest.Preferences
    PostgREST.ApiRequest.QueryParams PostgREST.ApiRequest.Types
    PostgREST.App PostgREST.AppState PostgREST.Auth PostgREST.CLI
    PostgREST.Config PostgREST.Config.Database PostgREST.Config.JSPath
    PostgREST.Config.PgVersion PostgREST.Config.Proxy PostgREST.Cors
    PostgREST.Error PostgREST.Logger PostgREST.MediaType PostgREST.Plan
    PostgREST.Plan.CallPlan PostgREST.Plan.MutatePlan
    PostgREST.Plan.ReadPlan PostgREST.Query
    PostgREST.Query.QueryBuilder PostgREST.Query.SqlFragment
    PostgREST.Query.Statements PostgREST.RangeQuery PostgREST.Response
    PostgREST.Response.GucHeader PostgREST.Response.OpenAPI
    PostgREST.SchemaCache PostgREST.SchemaCache.Identifiers
    PostgREST.SchemaCache.Proc PostgREST.SchemaCache.Relationship
    PostgREST.SchemaCache.Table PostgREST.Unix PostgREST.Version
    PostgREST.Workers

hidden-modules:       Paths_postgrest
import-dirs:          /usr/lib/ghc-9.6.6/site-local/postgrest-10.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/postgrest-10.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/postgrest-10.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/postgrest
hs-libraries:         HSpostgrest-10.1.0-EgJ93pZDzZuJRyYSfSIiN1
depends:
    HTTP-4000.5.0-EscuxuHOu98B2Bdr08BWwT
    Ranged-sets-0.5.0-26dVP97xV1G2ltqMVKwDAC
    aeson-2.2.2.0-D3gBId4buYWJLDjLSrsEfA
    auto-update-0.1.6-6H0t333beiuKHrlzkaC43b base-4.18.2.1
    base64-bytestring-1.2.1.0-KV8aVMC7eDp4VhaST1z1XE
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-2w7xRwFPLfwFgOPFogdG9O
    cassava-0.5.4.1-2g3Aqdsm0BHx7bWZYTjZE
    configurator-pg-0.2.11-2pYDZ3dem2XG3GALCQUiKO containers-0.6.7
    contravariant-extras-0.3.5.4-Jp1EzHgD0E5KQ707vKnuxI
    cookie-0.5.0-Dqi2dsQ09KG8Z0mbWITxu5 directory-1.3.8.5
    either-5.0.3-9OubONQRjKcHkZt5QRJXr4
    gitrev-1.3.1-HjgHeGOzFY1JvYhlt8eDSs
    hasql-1.6.1.1-4NTjpiOrvOu81G4wE7CuHZ
    hasql-dynamic-statements-0.3.1.2-r6lXaKxyxwIGtKMYr0onf
    hasql-notifications-0.2.0.5-ER5DdjaOjCeDBK0RtnmjAe
    hasql-pool-0.8.0.2-7SU9S22DoNlLHkM5ia9fFg
    hasql-transaction-1.0.1.2-1pTXTSwHR8e7qgr4sVammI
    heredoc-0.2.0.0-6fzsisYvDUd6tBbd4jIzIt
    http-types-0.12.4-KOR1gLg6ER2IlcqJ0qNtQq
    insert-ordered-containers-0.2.5.3-ChqosxWQKulAOKASdyUBjm
    interpolatedstring-perl6-1.0.2-1wEGY38mGfdH14fTF7YGOP
    jose-0.10.0.1-FXD2JaQBqHkJjiJi9y8Q0b
    lens-5.3.4-CugvPwDQfTKJtJ2DRsVKfV
    lens-aeson-1.2.3-Hq3Cic1JgcVB4UyNWupclv mtl-2.3.1
    network-3.1.4.0-6Vir8NKcwTtGDZOkjzNXEQ
    network-uri-2.6.4.2-9CHKirNVw9rJ9Z87o3gbmr
    optparse-applicative-0.18.1.0-7VN2J9FD8HH2Bl1L5dRVhn
    parsec-3.1.16.1 protolude-0.3.5-5kL54AsmHZ5CLwLjFAUNuU
    regex-tdfa-1.3.2.5-BeZN9DGCtsf7yikLZxv9p
    retry-0.9.3.1-FqrEYLn6eVQDy0b7zEKLN4
    scientific-0.3.8.1-5DbHtB8w5OO3mo7GyLG4Aa
    swagger2-2.8.10-CriiYVxsU2I31hqyrqxwQl text-2.0.2 time-1.12.2
    unix-2.8.4.0 unordered-containers-0.2.20.1-IS42DvcTPVH3F2RDVwits
    vault-0.3.1.6-GpEoifvtFnZC2iN22L9KJY
    vector-0.13.2.0-1mI63yzxbUH28Wn11C5uSI
    wai-3.2.4-JKCq5JcGzi0CtrYAeT794h
    wai-cors-0.2.7-7blYc3Zy46HJ9aAe3Ais5o
    wai-extra-3.1.18-7IXCHaDF71K3M0DXkppIKT
    wai-logger-2.5.0-FoEyiLq9IHY402T4GO6Ovh
    warp-3.4.0-2Kuv4AikhVQ7IUGEGfBGpl

haddock-interfaces:   /usr/share/doc/postgrest/html/postgrest.haddock
haddock-html:         /usr/share/doc/postgrest/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

